@@ -71,7 +71,8 @@ C<--test_files> argument.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<http://github.com/trwyant/perl-Astro-UTDF/issues>, or in electronic
+mail to the author.
 
 =head1 AUTHOR
 
@@ -79,7 +80,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009, 2012-2018 Thomas R. Wyant, III
+Copyright (C) 2009, 2012-2021 Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
