@@ -193,7 +193,8 @@ name by passing the desired name as the value of the C<name> key:
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<http://github.com/trwyant/perl-Astro-UTDF/issues>, or in electronic
+mail to the author.
 
 =head1 AUTHOR
 
@@ -201,7 +202,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010, 2012-2018 Thomas R. Wyant, III
+Copyright (C) 2010, 2012-2021 Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
