@@ -19,7 +19,7 @@ use constant SPEED_OF_LIGHT => 299792.458;	# Km/sec, per U.S. NIST
 use constant ARRAY_REF	=> ref [];
 use constant CODE_REF	=> ref sub {};
 
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 sub new {
     my $class = shift;
@@ -1761,7 +1761,8 @@ This information comes from byte 6 of the record.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-Astro-UTDF/issues>, or in electronic
+mail to the author.
 
 =head1 ACKNOWLEDGMENT
 
@@ -1774,7 +1775,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2019 Thomas R. Wyant, III
+Copyright (C) 2010-2021 Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
